@@ -18,12 +18,18 @@ class Context
     Vec2f offset{0, 0};
 
 public:
+    Vec2i clip_start{0,0};
+    Vec2i clip_size{0,0};
+
     Vec2f target_size;
     float vpscale = 1.0F;
 
     float line_width = 1;
+    float point_size = 2;
     gl_wrap::Color fg;
 
+    std::vector<float> points;
+
 private:
     Vec2f last_point{0,0};
 
@@ -85,5 +91,6 @@ public:
 
 
     void clear(gl_wrap::Color const& col) const;
+    void draw_polygon(const Vec2f* points, size_t count);
 };
 } // namespace pix
