@@ -12,6 +12,7 @@
 #include <chrono>
 #include <deque>
 #include <filesystem>
+#include <optional>
 #include <thread>
 #include <unordered_map>
 #include <unordered_set>
@@ -132,14 +133,10 @@ public:
         glfwWindowHint(GLFW_SCALE_TO_MONITOR, GLFW_TRUE);
         glfwWindowHint(GLFW_CONTEXT_VERSION_MAJOR, 2);
         glfwWindowHint(GLFW_CONTEXT_VERSION_MINOR, 1);
-        // glfwWindowHint(GLFW_OPENGL_FORWARD_COMPAT, GLFW_FALSE);
         glfwWindowHint(GLFW_OPENGL_PROFILE, GLFW_OPENGL_ANY_PROFILE);
 
         int width = settings.display_width;
         int height = settings.display_height;
-        if (width <= 0 || height <= 0) {
-            throw system_exception("Illegal window size");
-        }
         GLFWmonitor* monitor = nullptr;
         if (settings.screen == ScreenType::Full) {
             monitor = glfwGetPrimaryMonitor();
@@ -153,6 +150,9 @@ public:
                 height = mode->height;
             }
         }
+        if (width <= 0 || height <= 0) {
+            throw system_exception("Illegal window size");
+        }
         window = glfwCreateWindow(width, height, settings.title.c_str(),
                                   monitor, nullptr);
         if (window == nullptr) {
