@@ -14,7 +14,9 @@ namespace pix {
 class pix_exception : public std::exception
 {
 public:
-    explicit pix_exception(std::string m = "pix exception") : msg(std::move(m)) {}
+    explicit pix_exception(std::string m = "pix exception") : msg(std::move(m))
+    {
+    }
     const char* what() const noexcept override { return msg.c_str(); }
 
 private:
@@ -26,21 +28,21 @@ struct Image
     Image() = default;
     Image(int w, int h)
         : width(w),
-          height(h),
-          sptr{new std::byte[static_cast<size_t>(w) * h * 4]},
-          ptr{sptr.get()},
-          format{GL_RGBA}
-    {}
+          height(h), sptr{new std::byte[static_cast<size_t>(w) * h * 4]},
+          ptr{sptr.get()}, format{GL_RGBA}
+    {
+    }
     Image(int w, int h, std::byte* p, unsigned f = 0)
         : width(w), height(h), sptr{nullptr}, ptr{p}, format{f}
-    {}
+    {
+    }
 
     void flip() const
     {
-        for (int y=0; y<height/2; y++) {
-            auto* one = ptr + y*width*4;
-            auto* two = ptr + (height-1-y)*width*4;
-            std::swap_ranges(one, one + width*4, two);
+        for (int y = 0; y < height / 2; y++) {
+            auto* one = ptr + y * width * 4;
+            auto* two = ptr + (height - 1 - y) * width * 4;
+            std::swap_ranges(one, one + width * 4, two);
         }
     }
 
