@@ -56,28 +56,34 @@ inline auto add_image_class(py::module_ const& mod)
 
     // Image
     return py::class_<gl_wrap::TexRef>(mod, "Image")
-        .def(py::init<int32_t, int32_t>(), py::arg("width"), py::arg("height"))
-        .def(py::init<>(&image_from_vec2), py::arg("size"))
-        .def(py::init<>(&image_from_pixels), py::arg("width"),
-             py::arg("pixels"),
+        .def(py::init<int32_t, int32_t>(), "width"_a, "height"_a,
+             "Create an empty image of the given size.")
+        .def(py::init<>(&image_from_vec2), "size"_a,
+             "Create an empty image of the given size.")
+        .def(py::init<>(&image_from_pixels), "width"_a, "pixels"_a,
+             "Create an image from an array of 32-bit colors.")
+        .def("split", &split_wh, "cols"_a = -1, "rows"_a = -1, "width"_a = 8,
+             "height"_a = 8,
              "Splits the image into as many _width_ * _height_ images as "
              "possible, first going left to right, then top to bottom.")
-        .def("split", &split_wh, py::arg("cols") = -1, py::arg("rows") = -1,
-             py::arg("width") = 8, py::arg("height") = 8,
-             "Splits the image into as many _width_ * _height_ images as "
-             "possible, first going left to right, then top to bottom.")
-        .def("split", &split_size, py::arg("size"))
-        .def("bind", &gl::TexRef::bind, py::arg("unit") = 0)
+        .def("split", &split_size, "size"_a)
+        //.def("bind", &gl::TexRef::bind, "unit"_a = 0)
         .def("crop", &crop, "top_left"_a = std::nullopt,
-             "size"_a = std::nullopt)
-        .def("copy_from", &gl::TexRef::copy_from, py::arg("image"))
-        .def("copy_to", &gl::TexRef::copy_to, py::arg("image"))
-        .def("set_as_target", &gl::TexRef::set_target)
+             "size"_a = std::nullopt,
+             "Crop an image. Returns a view into the old image.")
+        .def("copy_from", &gl::TexRef::copy_from, "image"_a,
+             "Render one image into another.")
+        .def("copy_to", &gl::TexRef::copy_to, "image"_a,
+             "Render one image into another.")
+        //.def("set_as_target", &gl::TexRef::set_target)
         .def_property_readonly(
-            "pos", [](gl::TexRef const& t) { return Vec2f(t.x(), t.y()); })
+            "pos", [](gl::TexRef const& t) { return Vec2f(t.x(), t.y()); },
+            "The position of this image in its texture. Will normally be (0, "
+            "0) unless this image was split or cropped from another image.")
         .def_property_readonly(
             "size",
-            [](gl::TexRef const& t) { return Vec2f(t.width(), t.height()); })
+            [](gl::TexRef const& t) { return Vec2f(t.width(), t.height()); },
+            "Size of the image in (fractional) pixels.")
         .def_property_readonly("width", &gl_wrap::TexRef::width)
         .def_property_readonly("height", &gl_wrap::TexRef::height);
 }
